# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`fapolicyd`](#fapolicyd): A class for installing and configuring fapolicyd

### Defined types

* [`fapolicyd::rule_file`](#fapolicyd--rule_file): A type for managing fapolicyd rules files
* [`fapolicyd::trust_file`](#fapolicyd--trust_file): A type for managing fapolicyd trust files

### Functions

#### Private Functions

* `fapolicyd::format_rule`: A function for formatting a rule to be added to a .rules file
* `fapolicyd::get_trusted_file_info`: A function that returns the trusted application's file information in the format `<file absolute path> <file size> <file sha256 hash>`

### Data types

* [`Fapolicyd::Object`](#Fapolicyd--Object): A type for defining a fapolicyd rule object
* [`Fapolicyd::Rule`](#Fapolicyd--Rule): A type for defining a fapolicyd rule
* [`Fapolicyd::Subject`](#Fapolicyd--Subject): A type for defining a fapolicyd rule subject

## Classes

### <a name="fapolicyd"></a>`fapolicyd`

This class installs and configures fapolicyd

#### Examples

##### 

```puppet
include fapolicyd
```

#### Parameters

The following parameters are available in the `fapolicyd` class:

* [`package_ensure`](#-fapolicyd--package_ensure)
* [`service_ensure`](#-fapolicyd--service_ensure)
* [`service_enable`](#-fapolicyd--service_enable)
* [`permissive`](#-fapolicyd--permissive)
* [`nice_val`](#-fapolicyd--nice_val)
* [`q_size`](#-fapolicyd--q_size)
* [`uid`](#-fapolicyd--uid)
* [`gid`](#-fapolicyd--gid)
* [`do_stat_report`](#-fapolicyd--do_stat_report)
* [`detailed_report`](#-fapolicyd--detailed_report)
* [`db_max_size`](#-fapolicyd--db_max_size)
* [`subj_cache_size`](#-fapolicyd--subj_cache_size)
* [`obj_cache_size`](#-fapolicyd--obj_cache_size)
* [`watch_fs`](#-fapolicyd--watch_fs)
* [`trust`](#-fapolicyd--trust)
* [`integrity`](#-fapolicyd--integrity)
* [`syslog_format`](#-fapolicyd--syslog_format)
* [`rpm_sha256_only`](#-fapolicyd--rpm_sha256_only)
* [`allow_filesystem_mark`](#-fapolicyd--allow_filesystem_mark)

##### <a name="-fapolicyd--package_ensure"></a>`package_ensure`

Data type: `Enum['present', 'installed', 'absent']`

Set the state of the package

Default value: `'present'`

##### <a name="-fapolicyd--service_ensure"></a>`service_ensure`

Data type: `Enum['running', 'stopped']`

Set the state of the service

Default value: `'running'`

##### <a name="-fapolicyd--service_enable"></a>`service_enable`

Data type: `Boolean`

Set whether the service is enabled/disabled

Default value: `true`

##### <a name="-fapolicyd--permissive"></a>`permissive`

Data type: `Integer[0,1]`

Set to 0 to send policy decision to the kernel for enforcement.  Set to 1 to always allow access even if a policy would block it.

Default value: `0`

##### <a name="-fapolicyd--nice_val"></a>`nice_val`

Data type: `Integer[0,20]`

Set a process niceness value scheduler boost

Default value: `14`

##### <a name="-fapolicyd--q_size"></a>`q_size`

Data type: `Integer[1]`

Set the queue size for the internal queue that fapolicyd will use.

Default value: `800`

##### <a name="-fapolicyd--uid"></a>`uid`

Data type: `String[1]`

Set the uid or name of the user account under which fapolicy should switch to during startup

Default value: `'fapolicyd'`

##### <a name="-fapolicyd--gid"></a>`gid`

Data type: `String[1]`

Set the gid or name of the group under which fapolicy should switch to during startup

Default value: `'fapolicyd'`

##### <a name="-fapolicyd--do_stat_report"></a>`do_stat_report`

Data type: `Integer[0,1]`

Set whether fapolicy do should (1) or should not (0) create a usage statistics policy on shutdown

Default value: `1`

##### <a name="-fapolicyd--detailed_report"></a>`detailed_report`

Data type: `Integer[0,1]`

Set whether fapolicyd should(1) or should not(0) add subject and object information to the usage statistics report

Default value: `1`

##### <a name="-fapolicyd--db_max_size"></a>`db_max_size`

Data type: `Integer[1]`

Set how many megabytes to allow the trust database to grow to

Default value: `50`

##### <a name="-fapolicyd--subj_cache_size"></a>`subj_cache_size`

Data type: `Integer[1]`

Set how many entries the subject cache holds

Default value: `1549`

##### <a name="-fapolicyd--obj_cache_size"></a>`obj_cache_size`

Data type: `Integer[1]`

Set how  many entries the object cache holds

Default value: `8191`

##### <a name="-fapolicyd--watch_fs"></a>`watch_fs`

Data type: `Array[String[1]]`

Set a list of file systems that should be watched for access permission

Default value: `['ext2','ext3','ext4','tmpfs','xfs','vfat','iso9660','btrfs']`

##### <a name="-fapolicyd--trust"></a>`trust`

Data type: `Array[Enum['rpmdb','file'],1,2]`

Set list  of trust back-ends

Default value: `['rpmdb','file']`

##### <a name="-fapolicyd--integrity"></a>`integrity`

Data type: `Enum['none','size','ima','sha256']`

Set the integrity strategy that should be used

Default value: `'none'`

##### <a name="-fapolicyd--syslog_format"></a>`syslog_format`

Data type: `String[1]`

Set the format of the output from the access decision

Default value: `'rule,dec,perm,auid,pid,exe,:,path,ftype,trust'`

##### <a name="-fapolicyd--rpm_sha256_only"></a>`rpm_sha256_only`

Data type: `Integer[0,1]`

Set option (0 or 1) for whether the daemon should be forced to only work with SHA256 hashes

Default value: `0`

##### <a name="-fapolicyd--allow_filesystem_mark"></a>`allow_filesystem_mark`

Data type: `Integer[0,1]`

Set option (0 or 1) for whether to allow fapolicyd to monitor file access events on the underlying file system when they are bind
mounted or are overlayed

Default value: `0`

## Defined types

### <a name="fapolicyd--rule_file"></a>`fapolicyd::rule_file`

A type for managing fapolicyd rules files under `/etc/fapolicyd/rules.d/`

#### Examples

##### 

```puppet
fapolicyd::rule_file { 'myapps':
  priority => 80,
  comment  => 'Rules for myapps',
  rules    => [
    {
      decision => 'allow',
      perm     => 'execute',
       subjects => [
        {
          type    => 'exe',
          setting => '/usr/bin/bash',
        },
        {
          type    => 'trust',
          setting => '1',
        },
      ],
      objects  => [
        {
          type    => 'path',
          setting => '/tmp/ls',
        },
        {
          type    => 'ftype',
          setting => 'application/x-executable'
        },
        {
          type    => 'trust',
          setting => '0'
        },
      ]
    }
  ],
}
```

#### Parameters

The following parameters are available in the `fapolicyd::rule_file` defined type:

* [`priority`](#-fapolicyd--rule_file--priority)
* [`comment`](#-fapolicyd--rule_file--comment)
* [`rules`](#-fapolicyd--rule_file--rules)

##### <a name="-fapolicyd--rule_file--priority"></a>`priority`

Data type: `Integer[0]`

Priority of the rules in the rule file

Default value: `100`

##### <a name="-fapolicyd--rule_file--comment"></a>`comment`

Data type: `String[1]`

A comment to place into the rules file for describing the rules

Default value: `"${priority}-${title}.rules"`

##### <a name="-fapolicyd--rule_file--rules"></a>`rules`

Data type: `Array[Fapolicyd::Rule]`

An array of rules to add to the rules file

Default value: `[]`

### <a name="fapolicyd--trust_file"></a>`fapolicyd::trust_file`

A type for managing fapolicyd trust files under `/etc/fapolicyd/trust.d/`

#### Examples

##### 

```puppet
fapolicyd::trust_file { 'myapp':
  trusted_apps => [
    '/tmp/ls',
  ],
}
```

#### Parameters

The following parameters are available in the `fapolicyd::trust_file` defined type:

* [`trusted_apps`](#-fapolicyd--trust_file--trusted_apps)

##### <a name="-fapolicyd--trust_file--trusted_apps"></a>`trusted_apps`

Data type: `Array[Stdlib::Absolutepath]`

An array of the absolute path of applications to trust

Default value: `[]`

## Data types

### <a name="Fapolicyd--Object"></a>`Fapolicyd::Object`

A type for defining a fapolicyd rule object

Alias of

```puppet
Struct['type' => Enum['all','path','dir','device','ftype','trust','sha256hash'],
  'setting' => Optional[String[1]]]
```

### <a name="Fapolicyd--Rule"></a>`Fapolicyd::Rule`

A type for defining a fapolicyd rule

Alias of

```puppet
Struct['decision' => Enum['allow', 'deny', 'allow_audit', 'deny_audit', 'allow_syslog', 'deny_syslog', 'allow_log', 'deny_log'],
  'perm' => Optional[Enum['open', 'execute', 'any']],
  'subjects' => Array[Fapolicyd::Subject,1],
  'objects' => Array[Fapolicyd::Object]]
```

### <a name="Fapolicyd--Subject"></a>`Fapolicyd::Subject`

A type for defining a fapolicyd rule subject

Alias of

```puppet
Struct['type' => Enum['all','auid','uid','gid','sessionid','pid','ppid','trust','comm','exe','dir','ftype','device','pattern'],
  'setting' => Optional[Variant[String[1],Integer]]]
```

